@@ -1,6 +1,7 @@
 # Translation to R of C++ and Python code found here
 # https://www.geeksforgeeks.org/all-topological-sorts-of-a-directed-acyclic-graph/
-all_topological_sorts <- function(graph, path, discovered, n_items) {
+all_topological_sorts <- function(graph, n_items, env, path = integer(),
+                                  discovered = rep(FALSE, n_items)) {
   flag <- FALSE
 
   for (i in seq_len(n_items)) {
@@ -9,7 +10,7 @@ all_topological_sorts <- function(graph, path, discovered, n_items) {
 
       path <- c(path, i)
       discovered[[i]] <- TRUE
-      all_topological_sorts(graph, path, discovered, n_items)
+      all_topological_sorts(graph, n_items, env, path, discovered)
 
       attr(graph, "indegree")[graph[[i]]] <- attr(graph, "indegree")[graph[[i]]] + 1
       path <- path[-length(path)]
@@ -18,5 +19,9 @@ all_topological_sorts <- function(graph, path, discovered, n_items) {
       flag <- TRUE
     }
   }
-  if (length(path) == n_items) print(path)
+  if (length(path) == n_items) {
+    assign("x", c(get("x", envir = env), list(path)), envir = env)
+    assign("num", get("num", envir = env) + 1, envir = env)
+  }
 }
+
