@@ -10,8 +10,8 @@ logz_estimate <- estimate_partition_function(
 )
 
 # Calculating rho and alpha samples
-samples <- smc_mallows_new_users_complete(
-  R_obs = data, n_items = n_items, metric = metric,
+samples <- smc_mallows_new_users(
+  R_obs = data, type = "complete", n_items = n_items, metric = metric,
   leap_size = floor(n_items / 5), N = 100, Time = nrow(data) / num_new_obs,
   mcmc_kernel_app = 5, logz_estimate = logz_estimate,
   alpha_prop_sd = 0.1, lambda = 0.001, alpha_max = 1e6,
