@@ -1,9 +1,6 @@
 #ifndef MISSING_H
 #define MISSING_H
 
-#include <RcppArmadillo.h>
-#include "distances.h"
-#include "misc.h"
 
 void initialize_missing_ranks(arma::mat& rankings, const arma::umat& missing_indicator,
                               const arma::uvec& assessor_missing);
