@@ -1,7 +1,9 @@
-#include "RcppArmadillo.h"
+#include <RcppArmadillo.h>
 #include "smc.h"
 #include "partitionfuns.h"
 
+using namespace arma;
+
 // [[Rcpp::depends(RcppArmadillo)]]
 //' @title Metropolis-Hastings Alpha
 //' @description Function to perform Metropolis-Hastings for new rho under
@@ -48,17 +50,17 @@ double metropolis_hastings_alpha(
   const double lambda,
   const double alpha_max
 ) {
-  const double rand = Rcpp::as<double>(Rcpp::rnorm(1, 0, 1));
+  const double rand = R::rnorm(0, 1);
   const double alpha_prime_log = rand * alpha_prop_sd + std::log(alpha);
   const double alpha_prime = std::exp(alpha_prime_log);
 
   // Difference between current and proposed alpha
   const double& alpha_diff = alpha - alpha_prime;
-  const double mallows_loglik_prop = get_mallows_loglik(alpha_prime - alpha, rho, n_items, rankings, metric);
+  const double mallows_loglik_prop = get_exponent_sum(alpha_prime - alpha, rho, n_items, rankings, metric);
 
   // evaluate the log estimate of the partition function for a particular
   // value of alpha
-  const Rcpp::Nullable<arma::vec>& cardinalities = R_NilValue;
+  const Rcpp::Nullable<vec>& cardinalities = R_NilValue;
   const double logz_alpha = get_partition_function(n_items, alpha, cardinalities, logz_estimate, metric);
   const double logz_alpha_prime = get_partition_function(n_items, alpha_prime, cardinalities, logz_estimate, metric);
 
@@ -69,7 +71,7 @@ double metropolis_hastings_alpha(
 
   // determine whether to accept or reject proposed rho and return now consensus
   // ranking
-  const double p = Rcpp::as<double>(Rcpp::runif(1, 0, 1));
+  const double p = R::runif(0, 1);
   if (log(p) <= loga && alpha_prime < alpha_max) {
     return(alpha_prime);
   } else {
