@@ -5,10 +5,10 @@ alpha <- 2
 metric <- "footrule"
 n_items <- 6
 
-test_that("get_mallows_loglik() works as expected", {
+test_that("get_exponent_sum() works as expected", {
   set.seed(101)
-  loglik <- get_mallows_loglik(
-    alpha = alpha, rho = t(rho),  n_items = length(rho), rankings = t(rho),
+  loglik <- get_exponent_sum(
+    alpha = alpha, rho = t(rho), n_items = length(rho), rankings = t(rho),
     metric = metric
   )
   expect_equal(loglik, 0)
@@ -17,8 +17,8 @@ test_that("get_mallows_loglik() works as expected", {
     rho0 = rho, alpha0 = alpha, n_samples = 10,
     burnin = 1000, thinning = 500
   )
-  loglik <- get_mallows_loglik(
-    alpha = alpha, rho = rho,  n_items = n_items, rankings = rankings,
+  loglik <- get_exponent_sum(
+    alpha = alpha, rho = rho, n_items = n_items, rankings = rankings,
     metric = metric
   )
   expect_equivalent(loglik, -22.6667, tol = 1e-4)
@@ -35,12 +35,12 @@ test_that("smc_metropolis_hastings_rho() works as expected", {
   )
 
   # you can confirm the print statements inside the metropolis_hastings_rho
-  # match get_mallows_loglik and leap_and_shift_probs
+  # match get_exponent_sum and leap_and_shift_probs
   test_1 <- metropolis_hastings_rho(
     alpha = alpha, n_items = n_items, rankings = t(rho), metric = metric,
     rho = rho, leap_size = 1
   )
-  dist_1 <- BayesMallows:::get_rank_distance(rho, test_1, metric = "ulam")
+  dist_1 <- get_rank_distance(rho, test_1, metric = "ulam")
   expect_equal(test_1, as.matrix(c(1, 2, 3, 5, 4, 6)))
   # if rho != rho_prime, then it should have a ulam distance of 1
   # if rho == rho_prime, then it should have ulam distance of 0
@@ -50,7 +50,7 @@ test_that("smc_metropolis_hastings_rho() works as expected", {
     alpha = alpha, n_items = n_items, rankings = t(rho), metric = metric,
     rho = rho, leap_size = 2
   )
-  dist_2 <- BayesMallows:::get_rank_distance(rho, test_2, metric = "ulam")
+  dist_2 <- get_rank_distance(rho, test_2, metric = "ulam")
   expect_equal(test_2, as.matrix(c(1, 2, 3, 4, 5, 6)))
   expect_equal(dist_2, 0)
 
@@ -58,7 +58,7 @@ test_that("smc_metropolis_hastings_rho() works as expected", {
     alpha = alpha, n_items = n_items, rankings = t(rho), metric = metric,
     rho = rho, leap_size = 3
   )
-  dist_3 <- BayesMallows:::get_rank_distance(rho, test_3, metric = "ulam")
+  dist_3 <- get_rank_distance(rho, test_3, metric = "ulam")
   expect_equal(test_3, as.matrix(c(1, 2, 3, 4, 5, 6)))
   expect_equal(dist_3, 0)
 
@@ -67,7 +67,7 @@ test_that("smc_metropolis_hastings_rho() works as expected", {
     alpha = alpha, n_items = n_items, rankings = rankings, metric = metric,
     rho = rho, leap_size = 1
   )
-  dist_4 <- BayesMallows:::get_rank_distance(rho, test_4, metric = "ulam")
+  dist_4 <- get_rank_distance(rho, test_4, metric = "ulam")
   expect_equal(test_4, as.matrix(c(1, 2, 3, 4, 5, 6)))
   expect_equal(dist_4, 0)
 })
@@ -88,42 +88,36 @@ test_that("smc_leap_and_shift_probs() works as expected", {
 
   # if rho != rho_prime, then it should have a ulam distance of 1
   # if rho == rho_prime, then it should have ulam distance of 0
-  dist_1 <- BayesMallows:::get_rank_distance(rho, test_1$rho_prime, metric = "ulam")
+  dist_1 <- get_rank_distance(rho, test_1$rho_prime, metric = "ulam")
   expect_equal(dist_1, 1)
 
   test_2 <- leap_and_shift_probs(rho = rho, n_items = n_items, leap_size = 2)
-  expect_equal(test_2$rho_prime, as.matrix(c(1, 2, 3, 4, 5, 6)))
-  expect_equivalent(test_2$forwards_prob, 0.0556, tol = 1e-4)
-  expect_equivalent(test_2$backwards_prob, 0.0556, tol = 1e-4)
+  expect_equal(test_2$rho_prime, as.matrix(c(1, 2, 3, 5, 4, 6)))
+  expect_equivalent(test_2$forwards_prob, 0.09722222, tol = 1e-4)
+  expect_equivalent(test_2$backwards_prob, 0.09722222, tol = 1e-4)
 
-  dist_2 <- get_rank_distance(
-    rho, test_2$rho_prime, metric = "ulam"
-  )
-  expect_equal(dist_2, 0)
+  dist_2 <- get_rank_distance(rho, test_2$rho_prime, metric = "ulam")
+  expect_equal(dist_2, 1)
 
   test_3 <- leap_and_shift_probs(rho = rho, n_items = n_items, leap_size = 3)
-  expect_equal(test_3$rho_prime, as.matrix(c(1, 2, 3, 4, 5, 6)))
-  expect_equivalent(test_3$forwards_prob, 0.0417, tol = 1e-3)
-  expect_equivalent(test_3$backwards_prob, 0.0417, tol = 1e-3)
+  expect_equal(test_3$rho_prime, as.matrix(c(1, 3, 2, 4, 5, 6)))
+  expect_equivalent(test_3$forwards_prob, 0.075, tol = 1e-3)
+  expect_equivalent(test_3$backwards_prob, 0.075, tol = 1e-3)
 
-  dist_3 <- get_rank_distance(
-    rho, test_3$rho_prime, metric = "ulam"
-  )
-  expect_equal(dist_3, 0)
+  dist_3 <- get_rank_distance(rho, test_3$rho_prime, metric = "ulam")
+  expect_equal(dist_3, 1)
 })
 
 # ======================================================== #
 # unit test for metropolis_hastings_alpha.R                #
 # ======================================================== #
 
-metropolis_hastings_alpha_old <- function(
-  alpha, n_items, rankings, metric, rho, logz_estimate
-) {
+metropolis_hastings_alpha_old <- function(alpha, n_items, rankings, metric, rho, logz_estimate) {
   exp_alpha_prime <- rlnorm(1, mean = alpha, sd = 0.15) # 1
   alpha_prime <- log(exp_alpha_prime)
 
   # evaluate the log-likelihood with current rankings
-  mallows_loglik_prop <- get_mallows_loglik(
+  mallows_loglik_prop <- get_exponent_sum(
     alpha = (alpha_prime - alpha), rho = rho, n = n_items,
     rankings = rankings, metric = metric
   )
@@ -176,7 +170,8 @@ logz_estimate <- estimate_partition_function(
 set.seed(101)
 test_1_a <- metropolis_hastings_alpha_old(alpha, n_items, rankings, metric, rho, logz_estimate)
 test_1_b <- metropolis_hastings_alpha(
-  alpha, n_items, rankings, metric, rho, logz_estimate, alpha_prop_sd = 0.5,
+  alpha, n_items, rankings, metric, rho, logz_estimate,
+  alpha_prop_sd = 0.5,
   lambda = 0.1, alpha_max = 20
 )
 set.seed(101)
@@ -206,3 +201,25 @@ test_that("metropolis_hastings_alpha() works as expected", {
   expect_equivalent(test_3_b, 2)
   expect_equivalent(test_4_b, 1.904542, tol = 1e-5)
 })
+
+
+test_that("leap_and_shift_probs does not propose current ranking",{
+  set.seed(12)
+  count <- Reduce(`+`, lapply(list(1:4, 1:10), function(rho){
+    n_items = length(rho)
+    count <- 0
+    for(i in 1:20){
+      val <- leap_and_shift_probs(rho, 1, n_items)
+      if(all(val$rho_prime == rho)) {
+        count <- count + 1
+      }
+      val <- leap_and_shift_probs(rho, 2, n_items)
+      if(all(val$rho_prime == rho)) {
+        count <- count + 1
+      }
+    }
+    count
+  }))
+  expect_equal(count, 0)
+
+})
